[java-identity-provider COMMIT] in /trunk/idp-saml-impl/src: main/java/net/shibboleth/idp/saml/impl/profile/saml1/Add...

noreply at shibboleth.net noreply at shibboleth.net
Wed Jan 8 14:39:51 EST 2014


Author: scantor
Date: Wed Jan  8 14:39:50 2014
New Revision: 5166

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=5166&view=rev
Log:
IDP-193: Refactor and update for API changes

Modified:
    trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java
    trunk/idp-saml-impl/src/test/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertionTest.java

Modified: trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java?rev=5166&r1=5165&r2=5166&view=diff
==============================================================================
--- trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java (original)
+++ trunk/idp-saml-impl/src/main/java/net/shibboleth/idp/saml/impl/profile/saml1/AddAuthenticationStatementToAssertion.java Wed Jan  8 14:39:50 2014
@@ -18,19 +18,23 @@
 package net.shibboleth.idp.saml.impl.profile.saml1;
 
 import javax.annotation.Nonnull;
-
-import net.shibboleth.ext.spring.webflow.Event;
-import net.shibboleth.ext.spring.webflow.Events;
+import javax.annotation.Nullable;
+
+import net.shibboleth.idp.authn.AbstractAuthenticationAction;
+import net.shibboleth.idp.authn.AuthenticationException;
+import net.shibboleth.idp.authn.AuthenticationResult;
+import net.shibboleth.idp.authn.AuthnEventIds;
 import net.shibboleth.idp.authn.context.AuthenticationContext;
-import net.shibboleth.idp.profile.AbstractProfileAction;
-import net.shibboleth.idp.profile.ActionSupport;
+import net.shibboleth.idp.authn.principal.DefaultPrincipalDeterminationStrategy;
 import net.shibboleth.idp.profile.IdPEventIds;
 
-import org.opensaml.profile.ProfileException;
+import org.opensaml.profile.action.ActionSupport;
+import org.opensaml.profile.action.EventIds;
 import org.opensaml.profile.context.ProfileRequestContext;
+import org.opensaml.profile.context.navigate.OutboundMessageContextLookup;
 
 import net.shibboleth.idp.relyingparty.RelyingPartyContext;
-import net.shibboleth.idp.saml.profile.SAMLEventIds;
+import net.shibboleth.idp.saml.authn.principal.AuthenticationMethodPrincipal;
 import net.shibboleth.idp.saml.profile.saml1.SAML1ActionSupport;
 import net.shibboleth.utilities.java.support.component.ComponentSupport;
 import net.shibboleth.utilities.java.support.logic.Constraint;
@@ -38,39 +42,42 @@
 import org.joda.time.DateTime;
 import org.opensaml.core.xml.config.XMLObjectProviderRegistrySupport;
 import org.opensaml.messaging.context.navigate.ChildContextLookup;
+import org.opensaml.messaging.context.navigate.MessageLookup;
 import org.opensaml.saml.common.SAMLObjectBuilder;
 import org.opensaml.saml.saml1.core.Assertion;
 import org.opensaml.saml.saml1.core.AuthenticationStatement;
 import org.opensaml.saml.saml1.core.Response;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.springframework.webflow.execution.RequestContext;
 
 import com.google.common.base.Function;
+import com.google.common.base.Functions;
 
 /**
  * Builds an {@link AuthenticationStatement} and adds it to the {@link Response} set as the message of the
  * {@link ProfileRequestContext#getOutboundMessageContext()}. If the {@link Response} does not contain any
  * {@link Assertion} one will be created and added to it, otherwise the {@link AuthenticationStatement} will be added to
  * first {@link Assertion} in the {@link Response}.
  * 
  * A constructed {@link Assertion} will have its ID, issue instant, issuer, and version properties set. The issuer is
  * retrieved from the {@link org.opensaml.messaging.context.BasicMessageMetadataContext} on the
  * {@link ProfileRequestContext#getOutboundMessageContext()}.
  * 
  * The constructed {@link AuthenticationStatement} will have its authentication instant and method properties set. This
  * information is retrieved from the {@link AuthenticationRequestContext} on the {@link ProfileRequestContext}.
@@ -38,39 +42,42 @@
 
 /**
- * Builds an {@link AuthenticationStatement} and adds it to the {@link Response} set as the message of the
- * {@link ProfileRequestContext#getOutboundMessageContext()}. If the {@link Response} does not contain any
- * {@link Assertion} one will be created and added to it, otherwise the {@link AuthenticationStatement} will be added to
- * first {@link Assertion} in the {@link Response}.
- * 
- * A constructed {@link Assertion} will have its ID, issue instant, issuer, and version properties set. The issuer is
- * retrieved from the {@link org.opensaml.messaging.context.BasicMessageMetadataContext} on the
- * {@link ProfileRequestContext#getOutboundMessageContext()}.
- * 
- * The constructed {@link AuthenticationStatement} will have its authentication instant and method properties set. This
- * information is retrieved from the {@link AuthenticationRequestContext} on the {@link ProfileRequestContext}.
+ * Action that builds an {@link AuthenticationStatement} and adds it to the {@link Response} returned by a lookup
+ * strategy, by default the message returned by {@link ProfileRequestContext#getOutboundMessageContext()}.
+ * 
+ * <p>If the {@link Response} does not contain an {@link Assertion} one will be created and added to,
+ * otherwise the {@link AuthenticationStatement} will be added to first {@link Assertion} in the {@link Response},
+ * unless the option is set to preclude this.</p>
+ * 
+ * <p>A constructed {@link Assertion} will have its ID, IssueInstant, Issuer, and Version properties set.
+ * The issuer is based on {@link net.shibboleth.idp.relyingparty.RelyingPartyConfiguration#getResponderEntityId()}.</p>
+ * 
+ * <p>The {@link AuthenticationStatement} will have its authentication instant set, based on

[... 453 lines stripped ...]

[... 453 lines stripped ...]


More information about the commits mailing list